#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const lodash_1 = require("lodash");
const yargs_1 = __importDefault(require("yargs"));
const glob_1 = __importDefault(require("glob"));
function getBasePath() {
    const currentModuleRelativePath = lodash_1.get(require, 'main.filename');
    if (!currentModuleRelativePath)
        throw new Error('Unable to locate module path');
    const currentModuleAbsolutePath = path_1.default.dirname(currentModuleRelativePath);
    const pathComponents = currentModuleAbsolutePath.split('node_modules');
    const basePath = pathComponents.slice(0, pathComponents.length - 1).join('node_modules');
    return basePath;
}
function getConfig() {
    const args = yargs_1.default(process.argv).argv;
    const configFileName = args && args.config ? args.config : 'dsapidoc.json';
    const configFile = getBasePath() + configFileName;
    const config = JSON.parse(fs_1.default.readFileSync(configFile).toString());
    validateConfig(config);
    return config;
}
function validateConfig(config) {
    const { include, exclude } = config;
    if (!Array.isArray(include) || !Array.isArray(exclude))
        throw new Error('Malformed config file');
    [...include, ...exclude].forEach(e => {
        if (!/^\.\//.test(e))
            throw new Error('Paths must be relative to project root');
    });
}
function getFiles() {
    const { exclude, include } = getConfig();
    const ignore = exclude.map(item => getBasePath() + item.replace(/^\.\//, ''));
    const toInclude = include.reduce((all, item) => {
        const path = getBasePath() + item.replace(/^\.\//, '');
        const paths = glob_1.default.sync(path, { ignore });
        return [...new Set([...all, ...paths])];
    }, []);
    console.log(toInclude);
    return toInclude;
}
console.log(getFiles());
